User Guide
==========

This section contains guides and documents about Pyrodigal usage.

.. toctree::
   :maxdepth: 1
   :caption: Getting Started

    Installation <install>
    Parallelism <parallel>

.. toctree::
   :maxdepth: 1
   :caption: Resources

   Contribution Guide <contributing>
   Changelog <changes>
   Copyright Notice <copyright>